# grmpy

``grmpy``  is an open-source Python package for the simulation and estimation of the generalized Roy model. It serves as a teaching tool to promote the conceptual framework of the generalized Roy model, illustrate a variety of issues in the econometrics of policy evaluation, and showcases basic software engineering practices. <br>
Marginal Treatment Effects (MTE) can be estimated based on a parametric normal model or,
alternatively, via the semiparametric method of Local Instrumental Variables (LIV).

You can install ```grmpy``` either via pip

```
$ pip install grmpy
```
Or download it directly from our GitHub repository and install the package in editable mode

```
$ git clone https://github.com/OpenSourceEconomics/grmpy.git
$ pip install -e .
```

Please visit our [online documentation](http://grmpy.readthedocs.io/) for tutorials and more.

-----
[![docs passing](https://travis-ci.org/OpenSourceEconomics/grmpy.svg?branch=master)]()
[![license](https://img.shields.io/github/license/mashape/apistatus.svg?maxAge=2592000)]()
[![code style](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/python/black)
